@@ -1,18 +1,18 @@
-library(futile.logger)
 library(tryCatchLog)
 library(testthat)
 
-context("silent stacked warnings")
 
-# set up test context
-options("tryCatchLog.write.error.dump.file" = FALSE)
-options("tryCatchLog.silent.warnings"     = FALSE)
-options("tryCatchLog.silent.messages"     = FALSE)
+
+context("test_silent_stacked_warnings.R")
 
 
 
-flog.threshold("FATAL")                         # suppress logging of errors and warnings to avoid overly output
-# flog.threshold("INFO")
+source("init_unit_test.R")
+
+
+
+# suppress logging of errors and warnings to avoid overly output
+source("disable_logging_output.R")
 
 
 
